@@ -1,12 +1,19 @@
 import pandas as pd
 import numpy as np
 import datetime
+import os
 import pytd
 import requests
 import json
 
+##-- Declare ENV Variables from YML file
+apikey = os.environ['TD_API_KEY'] 
+tdserver = os.environ['TD_API_SERVER']
+sink_database = os.environ['SINK_DB']
+output_table = os.environ['OUTPUT_TABLE']
+
 ### --Function to create datamodel via API below
-def create_model(apikey=apikey, tdserver=tdserver, sink_database=sink_database, output_table=output_table):
+def create_model():
 
 #######USE Code Below if you prefer to use config file
     with open('config.json', 'r') as f:
